@@ -1,11 +1,9 @@
 #!/usr/bin/python
 ##
-## MPlot PlotPanel: a wx.Panel for 2D line plotting, using matplotlib
+## wxmplot ImagePanel: a wx.Panel for image display, using matplotlib
 ##
 
-import sys
 import time
-import os
 import wx
 from threading import Thread
 
@@ -228,8 +226,6 @@ class ImagePanel(BasePanel):
         self.gridspec.update(left=l, top=t, right=r, bottom=b)
 
         for ax in self.fig.get_axes():
-            # ax.update_params()
-            # ax.set_position(ax.figbox)
             figpos = ax.get_subplotspec().get_position(self.canvas.figure)
             ax.set_position(figpos)
 
@@ -672,10 +668,10 @@ class ImagePanel(BasePanel):
         except:
             return
         if len(self.conf.data.shape) == 3:
-            ymax, xmax, nc = self.conf.data.shape
+            ymax, xmax, _nc = self.conf.data.shape
         elif len(self.conf.data.shape) == 2:
             ymax, xmax = self.conf.data.shape
-            nc = 0
+            _nc = 0
         else:
             return
         if x < 0 or y < 0 or x > xmax or y > ymax:
